@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-11-20'; # DATE
-our $VERSION = '0.48'; # VERSION
+our $DATE = '2015-12-08'; # DATE
+our $VERSION = '0.49'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -592,7 +592,7 @@ sub _process_script {
                 for my $sc_name (@sc_names) {
                     my $sc_spec = $cli->{subcommands}{$sc_name};
                     next if $sc_spec->{is_alias};
-                    push @content, "=head2 For subcommand '$sc_name'\n\n";
+                    push @content, "=head2 Configuration for subcommand '$sc_name'\n\n";
                     $param2opts = $self->_list_config_params(
                         $clidocdata{$sc_name},
                         sub { !('common' ~~ @{ $_[0]->{tags} // []}) && $_[0]->{arg} });
@@ -670,7 +670,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.48 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-11-20.
+This document describes version 0.49 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-12-08.
 
 =head1 SYNOPSIS
 
